@@ -9,7 +9,6 @@
 #include <QGuiApplication>
 #include <QQuickItem>
 #include <QQuickRenderControl>
-#include <QQuickWindow>
 #include <QRegularExpression>
 #include <QWindow>
 
@@ -185,7 +184,7 @@ QWindow *MnemonicAttached::window() const
 
 void MnemonicAttached::onAltPressed()
 {
-    if (m_active || m_richTextLabel.isEmpty()) {
+    if (m_active || !m_enabled || m_richTextLabel.isEmpty()) {
         return;
     }
 
@@ -207,7 +206,7 @@ void MnemonicAttached::onAltReleased()
     }
 
     // Disabling menmonics again is always fine, e.g. on window deactivation,
-    // don't check for window is active here.
+    // don't check for enabled or window is active here.
 
     m_actualRichTextLabel = removeAcceleratorMarker(m_label);
     Q_EMIT richTextLabelChanged();
@@ -377,6 +376,7 @@ void MnemonicAttached::setLabel(const QString &text)
     m_label = text;
     updateSequence();
     Q_EMIT labelChanged();
+    Q_EMIT plainTextLabelChanged();
 }
 
 QString MnemonicAttached::richTextLabel() const
@@ -393,6 +393,11 @@ QString MnemonicAttached::mnemonicLabel() const
     return m_mnemonicLabel;
 }
 
+QString MnemonicAttached::plainTextLabel() const
+{
+    return removeAcceleratorMarker(m_label);
+}
+
 QString MnemonicAttached::label() const
 {
     return m_label;
@@ -494,3 +499,5 @@ void MnemonicAttached::setActive(bool active)
 }
 
 #include "mnemonicattached.moc"
+
+#include "moc_mnemonicattached.cpp"
